@@ -68,7 +68,7 @@ def montar_filtros(filtros):
 				lista = [ "'%s'" % x for x in sets_por_formato[valor] if x ]
 				clausules.append( " sigla in (%s) " % ','.join(lista) )
 			else:
-				clausules.append( " sigla = '%s' " % valor )
+				clausules.append( " sigla in (select sigla from colecao where descricao = '%s') " % valor )
 	print ' and '.join( clausules )
 	return ' and '.join( clausules )
 
@@ -115,10 +115,10 @@ class MagicPlugin:
 	attributes_card_columns = [ 'name', 'sigla', 'numero' ]
 	select_filters = ['Card Format','Card Set','Card Type']
 	
-	def get_select_filter_values(self, name):
+	def get_select_filter_values(self, name, conn):
 		filter_values = { 
 			'Card Format' : formatos, 
-			'Card Set' : legacy,
+			'Card Set' : [''] + conjunto.names_sets(conn, legacy),
 			'Card Type' : palavras_tipos.keys(),
 		}
 		return filter_values[name]
